@@ -14,6 +14,9 @@
 /* If true, include GNOME support */
 #undef ENABLE_GNOME
 
+/* Whether we are using Bonobo */
+#undef ENABLE_BONOBO
+
 /* for gettext ... */
 #undef HAVE_LC_MESSAGES
 #undef HAVE_STPCPY
@@ -21,6 +24,8 @@
 #undef HAVE_CATGETS
 #undef HAVE_GETTEXT
 
+#undef HAVE_UNISTD_H
+
 @BOTTOM@
 
 #ifdef DEBUG
