@@ -59,6 +59,10 @@ void glade_register_widgets(const GladeWidgetBuildData *widgets);
 /* set the current toplevel widget while building (use NULL to unset) */
 void glade_xml_set_toplevel(GladeXML *xml, GtkWindow *window);
 
+/* push and pop accelerator groups on a stack */
+GtkAccelGroup *glade_xml_push_accel(GladeXML *xml);
+GtkAccelGroup *glade_xml_pop_accel(GladeXML *xml);
+
 /* make sure that xml->priv->accel_group is a valid AccelGroup */
 GtkAccelGroup *glade_xml_ensure_accel(GladeXML *xml);
 
@@ -102,6 +106,12 @@ gint glade_enum_from_string(GtkType type, const char *string);
 /* a wrapper for gettext */
 char *glade_xml_gettext(GladeXML *xml, const char *msgid);
 
+/* invoke the custom widget creation function */
+GtkWidget *glade_create_custom(GladeXML *xml, gchar *func_name, gchar *name,
+			       gchar *string1, gchar *string2,
+			       gint int1, gint int2);
+
+
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
