@@ -565,6 +565,7 @@ toolbar_build_children (GladeXML *xml, GtkWidget *w, GladeWidgetInfo *info,
 		GladeWidgetInfo *cinfo = tmp->data;
 		GList *tmp2;
 		gboolean is_button = FALSE;
+		gchar *group_name = NULL;
 		GtkWidget *child;
 
 		for (tmp2 = cinfo->child_attributes; tmp2; tmp2 = tmp2->next) {
@@ -579,10 +580,10 @@ toolbar_build_children (GladeXML *xml, GtkWidget *w, GladeWidgetInfo *info,
 		for (tmp2 = cinfo->attributes; tmp2; tmp2 = tmp2->next) {
 			GladeAttribute *attr = tmp2->data;
 			if (!strcmp(attr->name, "child_name") &&
-			    !strcmp(attr->value, "Toolbar:button")) {
+			    !strcmp(attr->value, "Toolbar:button"))
 				is_button = TRUE;
-				break;
-			}
+			else if (!strcmp(attr->name, "group"))
+				group_name = attr->value;
 		}
 		if (is_button) {
 			char *label = NULL, *icon = NULL;
@@ -617,13 +618,32 @@ toolbar_build_children (GladeXML *xml, GtkWidget *w, GladeWidgetInfo *info,
 					GTK_TOOLBAR_CHILD_TOGGLEBUTTON, NULL,
 					_(label), NULL, NULL, iconw, NULL,
 					NULL);
-			else if (!strcmp(cinfo->class, "GtkRadioButton"))
+			else if (!strcmp(cinfo->class, "GtkRadioButton")) {
 				child = gtk_toolbar_append_element(
 					GTK_TOOLBAR(w),
 					GTK_TOOLBAR_CHILD_RADIOBUTTON, NULL,
 					_(label), NULL, NULL, iconw, NULL,
 					NULL);
-			else
+				if (group_name) {
+					GSList *group =
+						g_hash_table_lookup(
+						    xml->priv->radio_groups,
+						    group_name);
+
+					gtk_radio_button_set_group(
+						GTK_RADIO_BUTTON(child),
+						group);
+					if (!group)
+						group_name =
+							g_strdup(group_name);
+					g_hash_table_insert(
+						xml->priv->radio_groups,
+						group_name,
+						gtk_radio_button_group(
+						    GTK_RADIO_BUTTON(child)));
+				}
+
+			} else
 				child = gtk_toolbar_append_item(GTK_TOOLBAR(w),
 					_(label), NULL, NULL, iconw, NULL,
 					NULL);
@@ -1812,7 +1832,8 @@ menuitem_new(GladeXML *xml, GladeWidgetInfo *info)
 			if (accel)
 				gtk_widget_add_accelerator(menuitem,
 							   "activate_item",
-							   accel, key, 0, 0);
+							   accel, key, 0,
+							   0);
 			else {
 				/* not inside a GtkMenu -- must be on menubar*/
 				accel = glade_xml_ensure_accel(xml);
@@ -1866,7 +1887,8 @@ checkmenuitem_new(GladeXML *xml, GladeWidgetInfo *info)
 		if (accel)
 			gtk_widget_add_accelerator(menuitem,
 						   "activate_item",
-						   accel, key, 0, 0);
+						   accel, key, 0,
+						   0);
 		else {
 			/* not inside a GtkMenu -- must be on menubar*/
 			accel = glade_xml_ensure_accel(xml);
@@ -1893,6 +1915,8 @@ radiomenuitem_new(GladeXML *xml, GladeWidgetInfo *info)
 	GList *tmp;
 	char *label = NULL;
 	gboolean right = FALSE, active = FALSE, toggle = FALSE;
+	GSList *group = NULL;
+	char *group_name = NULL;
 
 	for (tmp = info->attributes; tmp; tmp = tmp->next) {
 		GladeAttribute *attr = tmp->data;
@@ -1905,10 +1929,16 @@ radiomenuitem_new(GladeXML *xml, GladeWidgetInfo *info)
 			active = attr->value[0] == 'T';
 		else if (!strcmp(attr->name, "always_show_toggle"))
 			toggle = attr->value[0] == 'T';
+		else if (!strcmp(attr->name, "group")) {
+			group_name = attr->value;
+			group = g_hash_table_lookup(xml->priv->radio_groups,
+						    group_name);
+			if (!group)
+				group_name = g_strdup(group_name);
+		}
 	}
 
-	/* XXXX -- must do something about radio item groups ... */
-	menuitem = gtk_radio_menu_item_new_with_label(NULL, "");
+	menuitem = gtk_radio_menu_item_new_with_label(group, "");
 	if (label){
 		char *s = label [0] ? _(label) : "";
 		
@@ -1921,7 +1951,8 @@ radiomenuitem_new(GladeXML *xml, GladeWidgetInfo *info)
 		if (accel)
 			gtk_widget_add_accelerator(menuitem,
 						   "activate_item",
-						   accel, key, 0, 0);
+						   accel, key, 0,
+						   0);
 		else {
 			/* not inside a GtkMenu -- must be on menubar*/
 			accel = glade_xml_ensure_accel(xml);
@@ -1934,6 +1965,12 @@ radiomenuitem_new(GladeXML *xml, GladeWidgetInfo *info)
 
 	if (right)
 		gtk_menu_item_right_justify(GTK_MENU_ITEM(menuitem));
+	if (group_name) {
+		GtkRadioMenuItem *radio = GTK_RADIO_MENU_ITEM(menuitem);
+		g_hash_table_insert(xml->priv->radio_groups,
+				    group_name,
+				    gtk_radio_menu_item_group(radio));
+	}
 	gtk_check_menu_item_set_state(GTK_CHECK_MENU_ITEM(menuitem), active);
 	gtk_check_menu_item_set_show_toggle(GTK_CHECK_MENU_ITEM(menuitem), toggle);
 
@@ -2234,7 +2271,7 @@ hpaned_new(GladeXML *xml, GladeWidgetInfo *info)
 		else if (!strcmp(attr->name, "gutter_size"))
 			gtk_paned_set_gutter_size(GTK_PANED(paned),
 						  strtoul(attr->value,NULL,0));
-		else if (!strcmp(attr, "position"))
+		else if (!strcmp(attr->name, "position"))
 			gtk_paned_set_position(GTK_PANED(paned),
 					       strtol(attr->value, NULL, 0));
 	}
@@ -2256,7 +2293,7 @@ vpaned_new(GladeXML *xml, GladeWidgetInfo *info)
 		else if (!strcmp(attr->name, "gutter_size"))
 			gtk_paned_set_gutter_size(GTK_PANED(paned),
 						  strtoul(attr->value,NULL,0));
-		else if (!strcmp(attr, "position"))
+		else if (!strcmp(attr->name, "position"))
 			gtk_paned_set_position(GTK_PANED(paned),
 					       strtol(attr->value, NULL, 0));
 	}
@@ -2708,20 +2745,10 @@ inputdialog_new (GladeXML *xml, GladeWidgetInfo *info)
 static GtkWidget *
 custom_new (GladeXML *xml, GladeWidgetInfo *info)
 {
-	typedef GtkWidget *(* create_func)(gchar *name,
-					   gchar *string1, gchar *string2,
-					   gint int1, gint int2);
 	GtkWidget *wid = NULL;
 	GList *tmp;
 	gchar *func_name = NULL, *string1 = NULL, *string2 = NULL;
 	gint int1 = 0, int2 = 0;
-	create_func func;
-	GModule *allsymbols;
-
-	if (!g_module_supported()) {
-		g_error("custom_new requires gmodule to work correctly");
-		return NULL;
-	}
 
 	for (tmp = info->attributes; tmp; tmp = tmp->next) {
 		GladeAttribute *attr = tmp->data;
@@ -2737,11 +2764,11 @@ custom_new (GladeXML *xml, GladeWidgetInfo *info)
 		else if (!strcmp(attr->name, "int2"))
 			int2 = strtol(attr->value, NULL, 0);
 	}
-	allsymbols = g_module_open(NULL, 0);
-	if (g_module_symbol(allsymbols, func_name, (gpointer *)&func))
-		wid = func(info->name, string1, string2, int1, int2);
-	else
-		g_warning("could not func widget creation function");
+	wid = glade_create_custom(xml, func_name, info->name, string1,
+				  string2, int1, int2);
+	/* fallback to prevent segfault */
+	if (wid == NULL)
+		wid = gtk_label_new("[custom widget creation failed]");
 	return wid;
 }
 
